==> dojo_1.5.0+dfsg.orig.tar.gz: dojo-release-1.5.0-src+dfsg/dojox/editor/plugins/nls/ro/latinEntities.js <==
({
	/* These are already handled in the default RTE
		amp:"ampersand",lt:"less-than sign",
		gt:"greater-than sign",
		nbsp:"no-break space\nnon-breaking space",
		quot:"quote",
	*/
	iexcl:"semnul exclamării inversat",
	cent:"semnul cent",
	pound:"semnul liră sterlină",
	curren:"semnul monedă",
	yen:"semnul yen\nsemnul nyuan",
	brvbar:"bară ruptă\nbară verticală ruptă",
	sect:"semn secţiune",
	uml:"tremă\ntremă de spaţiere",
	copy:"semnul copyright",
	ordf:"indicator ordinal feminin",
	laquo:"ghilimele unghi dublu arătând spre stânga\nghilimele arătând spre stânga",
	not:"semn nu",
	shy:"liniuţă de despărţire soft\nliniuţă de despărţire discreţionară",
	reg:"semn de înregistrare\nsemn de marcă înregistrată",
	macr:"macron\nmacron de spaţiere\nlinie deasupra\nAPL linie deasupra",
	deg:"semn de grade",
	plusmn:"semn plus-minus\nsemn plus-sau-minus",
	sup2:"scriere indice superior doi\nscriere indice superior cifră doi\npătrat",
	sup3:"scriere indice superior trei\nscriere indice superior cifră trei\ncub",
	acute:"accent acut\nspaţiere acută",
	micro:"semn micro",
	para:"semn pilcrow\nsemn paragraf",
	middot:"punct de mijloc\nvirgulă georgiană\npunct de mijloc grec",
	cedil:"sedila\nsedila de spaţiere",
	sup1:"scriere indice superior unu\nscriere indice superior cifră unu",
	ordm:"indicator ordinal masculin",
	raquo:"ghilimele unghi dublu arătând spre dreapta\nghilimele arătând spre dreapta",
	frac14:"fracţie ordinară un sfert\nfracţie un sfert",
	frac12:"fracţie ordinară o jumătate\nfracţie o jumătate",
	frac34:"fracţie ordinară trei sferturi\nfracţie trei sferturi",
	iquest:"semn de întrebare inversat\nsemn de întrebare răsturnat",
	Agrave:"Literă mare latină A cu accent grav\nLiteră mare latină A grav",
	Aacute:"Literă mare latină A cu accent acut",
	Acirc:"Literă mare latină A cu circumflex",
	Atilde:"Literă mare latină A cu tilda",
	Auml:"Literă mare latină A cu tremă",
	Aring:"Literă mare latină A cu inel deasupra\nLiteră mare latină A cu inel",
	AElig:"Literă mare latină AE\nLigatură mare latină AE",
	Ccedil:"Literă mare latină C cu sedilă",
	Egrave:"Literă mare latină E cu accent grav",
	Eacute:"Literă mare latină E cu accent acut",
	Ecirc:"Literă mare latină E cu circumflex",
	Euml:"Literă mare latină E cu tremă",
	Igrave:"Literă mare latină I cu accent grav",
	Iacute:"Literă mare latină I cu accent acut",
	Icirc:"Literă mare latină I cu circumflex",
	Iuml:"Literă mare latină I cu tremă",
	ETH:"Literă mare latină ETH",
	Ntilde:"Literă mare latină N cu tilda",
	Ograve:"Literă mare latină O cu accent grav",
	Oacute:"Literă mare latină O cu accent acut",
	Ocirc:"Literă mare latină O cu circumflex",
	Otilde:"Literă mare latină O cu tilda",
	Ouml:"Literă mare latină O cu tremă",
	times:"semn de înmulţire",
	Oslash:"Literă latină majusculă O cu linie de taiere\nLiteră latină majusculă O cu o linie oblică",
	Ugrave:"Literă mare latină U cu accent grav",
	Uacute:"Literă mare latină U cu accent acut",
	Ucirc:"Literă mare latină U cu circumflex",
	Uuml:"Literă mare latină U cu tremă",
	Yacute:"Literă mare latină Y cu accent acut",
	THORN:"Literă mare latină THORN",
	szlig:"Literă latină mică s diez\ness-zed",
	agrave:"Literă latină mică a cu accent grav\nLiteră latină mică a grav",
	aacute:"Literă latină mică a cu accent acut",
	acirc:"Literă latină mică a cu circumflex",
	atilde:"Literă latină mică a cu tilda",
	auml:"Literă latină mică a cu tremă",
	aring:"Literă latină mică a cu inel deasupra\nLiteră latină mică a cu inel",
	aelig:"Literă latină mică ae\nLigatură latină mică ae",
	ccedil:"Literă latină mică c cu sedilă",
	egrave:"Literă latină mică e cu accent grav",
	eacute:"Literă latină mică e cu accent acut",
	ecirc:"Literă latină mică e cu circumflex",
	euml:"Literă latină mică e cu tremă",
	igrave:"Literă latină mică i cu accent grav",
	iacute:"Literă latină mică i cu accent acut",
	icirc:"Literă latină mică i cu circumflex",
	iuml:"Literă latină mică i cu tremă",
	eth:"Literă latină mică eth",
	ntilde:"Literă latină mică n cu tilda",
	ograve:"Literă latină mică o cu accent grav",
	oacute:"Literă latină mică o cu accent acut",
	ocirc:"Literă latină mică o cu circumflex",
	otilde:"Literă latină mică o cu tilda",
	ouml:"Literă latină mică o cu tremă",
	divide:"semn împărţire",
	oslash:"Literă latină mică o cu linie de taiere\nLiteră latină mică o cu o linie oblică",
	ugrave:"Literă latină mică u cu accent grav",
	uacute:"Literă latină mică u cu accent acut",
	ucirc:"Literă latină mică u cu circumflex",
	uuml:"Literă latină mică u cu tremă",
	yacute:"Literă latină mică y cu accent acut",
	thorn:"Literă latină mică thorn",
	yuml:"Literă latină mică y cu tremă",

// Greek Characters and Symbols
	fnof:"Literă latină mică f cu cârlig\nfuncţie\nflorin",
	Alpha:"Literă greacă mare alfa",
	Beta:"Literă greacă mare beta",
	Gamma:"Literă greacă mare gamma",
	Delta:"Literă greacă mare delta",
	Epsilon:"Literă greacă mare epsilon",
	Zeta:"Literă greacă mare zeta",
	Eta:"Literă greacă mare eta",
	Theta:"Literă greacă mare theta",
	Iota:"Literă greacă mare iota",
	Kappa:"Literă greacă mare kappa",
	Lambda:"Literă greacă mare lambda",
	Mu:"Literă greacă mare miu",
	Nu:"Literă greacă mare niu",
	Xi:"Literă greacă mare xi",
	Omicron:"Literă greacă mare omicron",
	Pi:"Literă greacă mare pi",
	Rho:"Literă greacă mare rho",
	Sigma:"Literă greacă mare sigma",
	Tau:"Literă greacă mare tau",
	Upsilon:"Literă greacă mare upsilon",
	Phi:"Literă greacă mare phi",
	Chi:"Literă greacă mare chi",
	Psi:"Literă greacă mare psi",
	Omega:"Literă greacă mare omega",
	alpha:"Literă greacă mică alfa",
	beta:"Literă greacă mică beta",
	gamma:"Literă greacă mică gamma",
	delta:"Literă greacă mică delta",
	epsilon:"Literă greacă mică epsilon",
	zeta:"Literă greacă mică zeta",
	eta:"Literă greacă mică eta",
	theta:"Literă greacă mică theta",
	iota:"Literă greacă mică iota",
	kappa:"Literă greacă mică kappa",
	lambda:"Literă greacă mică lambda",
	mu:"Literă greacă mică miu",
	nu:"Literă greacă mică niu",
	xi:"Literă greacă mică xi",
	omicron:"Literă greacă mică omicron",
	pi:"Literă greacă mică pi",
	rho:"Literă greacă mică rho",
	sigmaf:"Literă greacă mică sigma final",
	sigma:"Literă greacă mică sigma",
	tau:"Literă greacă mică tau",
	upsilon:"Literă greacă mică upsilon",
	phi:"Literă greacă mică phi",
	chi:"Literă greacă mică chi",
	psi:"Literă greacă mică psi",
	omega:"Literă greacă mică omega",
	thetasym:"Literă greacă mică simbol theta",
	upsih:"Simbolul grec upsilon cu cârlig",
	piv:"Simbolul grec pi",
	bull:"bullet\ncerc mic negru",
	hellip:"elipse orizontale\ntrei puncte precursoare",
	prime:"prim\nminute\npicioare",
	Prime:"prim dublu\nsecunde\nţoli",
	oline:"linie deasupra\nlinie de spaţiere deasupra",
	frasl:"linie fracţie",
	weierp:"script capital P\nputere\np Weierstrass",
	image:"I majusculă înnegrită\nparte imaginară",
	real:"R majusculă înnegrită\nsimbol parte reală",
	trade:"semn marcă înregistrată",
	alefsym:"simbol alef\nprimul cardinal transfinit",
	larr:"săgeată spre stânga",
	uarr:"săgeata în sus",
	rarr:"săgeată spre dreapta",
	darr:"săgeata în jos",
	harr:"săgeata stânga dreapta",
	crarr:"săgeata în jos cu colţ spre stânga",
	lArr:"săgeata dublă spre stânga",
	uArr:"săgeata dublă în sus",
	rArr:"săgeata dublă spre dreapta",
	dArr:"săgeata dublă în jos",
	hArr:"săgeata dublă stânga dreapta",
	forall:"pentru toate",
	part:"diferenţiale parţiale",
	exist:"Există",
	empty:"set gol\nset zero\ndiametru",
	nabla:"nabla\ndiferenţa înapoi",
	isin:"element al",
	notin:"nu este un element al",
	ni:"conţine ca membru",
	prod:"n produs\nsemnul produs",
	sum:"n suma",
	minus:"semnul minus",
	lowast:"operatorul asterisk",
	radic:"rădăcină pătrată\nsemnul radical",
	prop:"proporţional cu",
	infin:"infinit",
	ang:"unghi",
	and:"şi logic\npană",
	or:"sau logic\nV",
	cap:"intersecţie\ncăciulă",
	cup:"reuniune\ncupă","int":"integral",
	there4:"de aceea",
	sim:"operator tilda\nvariază cu\nsimilar cu",
	cong:"aproximativ egal cu",
	asymp:"aproape egal cu\nasimptotic la",
	ne:"nu este egal cu",
	equiv:"identic cu",
	le:"mai mic sau egal cu",
	ge:"mai mare sau egal cu",
	sub:"subset al",
	sup:"superset al",
	nsub:"nu este un subset al",
	sube:"subset al sau egal cu",
	supe:"superset al sau egal cu",
	oplus:"plus încercuit\nsumă directă",
	otimes:"multiplicator încercuit\nprodus vectorial",
	perp:"t întors\nortogonal la\nerpendicular",
	sdot:"operator punct",
	lceil:"plafon stânga\nAPL upstile",
	rceil:"plafon dreapta",
	lfloor:"podea stânga\nAPL downstile",
	rfloor:"podea dreapta",
	lang:"paranteză unghiulară spre stânga",
	rang:"paranteză unghiulară spre dreapta",
	loz:"romb",
	spades:"treflă neagră",
	clubs:"pică neagră\nshamrock",
	hearts:"inimă neagră\nvalentine",
	diams:"romb negru",
	OElig:"Ligatură mare latină OE",
	oelig:"Ligatură mică latină oe",
	Scaron:"Literă mare latină S cu caron",
	scaron:"Literă mică latină s cu caron",
	Yuml:"Literă mare latină Y cu tremă",
	circ:"accent circumflex modificator de literă",
	tilde:"tilda mică",
	ensp:"spaţiu en",
	emsp:"spaţiu em",
	thinsp:"spaţiu îngust",
	zwnj:"zero fără unificator",
	zwj:"zero cu unificator",
	lrm:"semn stânga spre dreapta",
	rlm:"semn dreapta spre stânga",
	ndash:"linie en",
	mdash:"linie em",
	lsquo:"ghilimele simple stânga",
	rsquo:"ghilimele simple dreapta",
	sbquo:"single low-9 semn de citare ",
	ldquo:"ghilimele duble stânga",
	rdquo:"ghilimele duble dreapta",
	bdquo:"double low-9 semn de citare",
	dagger:"cruce",
	Dagger:"cruce dublă",
	permil:"semn per mie",
	lsaquo:"ghilimele singure unghiulare spre stânga",
	rsaquo:"ghilimele singure unghiulare spre dreapta",
	euro:"semn euro"
})

==> dojo_1.7.2+dfsg.orig.tar.gz: dojo-release-1.7.2-src+dfsg/dojox/editor/plugins/nls/ro/latinEntities.js <==
define(
//begin v1.x content
({
	/* These are already handled in the default RTE
		amp:"ampersand",lt:"less-than sign",
		gt:"greater-than sign",
		nbsp:"no-break space\nnon-breaking space",
		quot:"quote",
	*/
	iexcl:"semnul exclamării inversat",
	cent:"semnul cent",
	pound:"semnul liră sterlină",
	curren:"semnul monedă",
	yen:"semnul yen\nsemnul nyuan",
	brvbar:"bară ruptă\nbară verticală ruptă",
	sect:"semn secţiune",
	uml:"tremă\ntremă de spaţiere",
	copy:"semnul copyright",
	ordf:"indicator ordinal feminin",
	laquo:"ghilimele unghi dublu arătând spre stânga\nghilimele arătând spre stânga",
	not:"semn nu",
	shy:"liniuţă de despărţire soft\nliniuţă de despărţire discreţionară",
	reg:"semn de înregistrare\nsemn de marcă înregistrată",
	macr:"macron\nmacron de spaţiere\nlinie deasupra\nAPL linie deasupra",
	deg:"semn de grade",
	plusmn:"semn plus-minus\nsemn plus-sau-minus",
	sup2:"scriere indice superior doi\nscriere indice superior cifră doi\npătrat",
	sup3:"scriere indice superior trei\nscriere indice superior cifră trei\ncub",
	acute:"accent acut\nspaţiere acută",
	micro:"semn micro",
	para:"semn pilcrow\nsemn paragraf",
	middot:"punct de mijloc\nvirgulă georgiană\npunct de mijloc grec",
	cedil:"sedila\nsedila de spaţiere",
	sup1:"scriere indice superior unu\nscriere indice superior cifră unu",
	ordm:"indicator ordinal masculin",
	raquo:"ghilimele unghi dublu arătând spre dreapta\nghilimele arătând spre dreapta",
	frac14:"fracţie ordinară un sfert\nfracţie un sfert",
	frac12:"fracţie ordinară o jumătate\nfracţie o jumătate",
	frac34:"fracţie ordinară trei sferturi\nfracţie trei sferturi",
	iquest:"semn de întrebare inversat\nsemn de întrebare răsturnat",
	Agrave:"Literă mare latină A cu accent grav\nLiteră mare latină A grav",
	Aacute:"Literă mare latină A cu accent acut",
	Acirc:"Literă mare latină A cu circumflex",
	Atilde:"Literă mare latină A cu tilda",
	Auml:"Literă mare latină A cu tremă",
	Aring:"Literă mare latină A cu inel deasupra\nLiteră mare latină A cu inel",
	AElig:"Literă mare latină AE\nLigatură mare latină AE",
	Ccedil:"Literă mare latină C cu sedilă",
	Egrave:"Literă mare latină E cu accent grav",
	Eacute:"Literă mare latină E cu accent acut",
	Ecirc:"Literă mare latină E cu circumflex",
	Euml:"Literă mare latină E cu tremă",
	Igrave:"Literă mare latină I cu accent grav",
	Iacute:"Literă mare latină I cu accent acut",
	Icirc:"Literă mare latină I cu circumflex",
	Iuml:"Literă mare latină I cu tremă",
	ETH:"Literă mare latină ETH",
	Ntilde:"Literă mare latină N cu tilda",
	Ograve:"Literă mare latină O cu accent grav",
	Oacute:"Literă mare latină O cu accent acut",
	Ocirc:"Literă mare latină O cu circumflex",
	Otilde:"Literă mare latină O cu tilda",
	Ouml:"Literă mare latină O cu tremă",
	times:"semn de înmulţire",
	Oslash:"Literă latină majusculă O cu linie de taiere\nLiteră latină majusculă O cu o linie oblică",
	Ugrave:"Literă mare latină U cu accent grav",
	Uacute:"Literă mare latină U cu accent acut",
	Ucirc:"Literă mare latină U cu circumflex",
	Uuml:"Literă mare latină U cu tremă",
	Yacute:"Literă mare latină Y cu accent acut",
	THORN:"Literă mare latină THORN",
	szlig:"Literă latină mică s diez\ness-zed",
	agrave:"Literă latină mică a cu accent grav\nLiteră latină mică a grav",
	aacute:"Literă latină mică a cu accent acut",
	acirc:"Literă latină mică a cu circumflex",
	atilde:"Literă latină mică a cu tilda",
	auml:"Literă latină mică a cu tremă",
	aring:"Literă latină mică a cu inel deasupra\nLiteră latină mică a cu inel",
	aelig:"Literă latină mică ae\nLigatură latină mică ae",
	ccedil:"Literă latină mică c cu sedilă",
	egrave:"Literă latină mică e cu accent grav",
	eacute:"Literă latină mică e cu accent acut",
	ecirc:"Literă latină mică e cu circumflex",
	euml:"Literă latină mică e cu tremă",
	igrave:"Literă latină mică i cu accent grav",
	iacute:"Literă latină mică i cu accent acut",
	icirc:"Literă latină mică i cu circumflex",
	iuml:"Literă latină mică i cu tremă",
	eth:"Literă latină mică eth",
	ntilde:"Literă latină mică n cu tilda",
	ograve:"Literă latină mică o cu accent grav",
	oacute:"Literă latină mică o cu accent acut",
	ocirc:"Literă latină mică o cu circumflex",
	otilde:"Literă latină mică o cu tilda",
	ouml:"Literă latină mică o cu tremă",
	divide:"semn împărţire",
	oslash:"Literă latină mică o cu linie de taiere\nLiteră latină mică o cu o linie oblică",
	ugrave:"Literă latină mică u cu accent grav",
	uacute:"Literă latină mică u cu accent acut",
	ucirc:"Literă latină mică u cu circumflex",
	uuml:"Literă latină mică u cu tremă",
	yacute:"Literă latină mică y cu accent acut",
	thorn:"Literă latină mică thorn",
	yuml:"Literă latină mică y cu tremă",

// Greek Characters and Symbols
	fnof:"Literă latină mică f cu cârlig\nfuncţie\nflorin",
	Alpha:"Literă greacă mare alfa",
	Beta:"Literă greacă mare beta",
	Gamma:"Literă greacă mare gamma",
	Delta:"Literă greacă mare delta",
	Epsilon:"Literă greacă mare epsilon",
	Zeta:"Literă greacă mare zeta",
	Eta:"Literă greacă mare eta",
	Theta:"Literă greacă mare theta",
	Iota:"Literă greacă mare iota",
	Kappa:"Literă greacă mare kappa",
	Lambda:"Literă greacă mare lambda",
	Mu:"Literă greacă mare miu",
	Nu:"Literă greacă mare niu",
	Xi:"Literă greacă mare xi",
	Omicron:"Literă greacă mare omicron",
	Pi:"Literă greacă mare pi",
	Rho:"Literă greacă mare rho",
	Sigma:"Literă greacă mare sigma",
	Tau:"Literă greacă mare tau",
	Upsilon:"Literă greacă mare upsilon",
	Phi:"Literă greacă mare phi",
	Chi:"Literă greacă mare chi",
	Psi:"Literă greacă mare psi",
	Omega:"Literă greacă mare omega",
	alpha:"Literă greacă mică alfa",
	beta:"Literă greacă mică beta",
	gamma:"Literă greacă mică gamma",
	delta:"Literă greacă mică delta",
	epsilon:"Literă greacă mică epsilon",
	zeta:"Literă greacă mică zeta",
	eta:"Literă greacă mică eta",
	theta:"Literă greacă mică theta",
	iota:"Literă greacă mică iota",
	kappa:"Literă greacă mică kappa",
	lambda:"Literă greacă mică lambda",
	mu:"Literă greacă mică miu",
	nu:"Literă greacă mică niu",
	xi:"Literă greacă mică xi",
	omicron:"Literă greacă mică omicron",
	pi:"Literă greacă mică pi",
	rho:"Literă greacă mică rho",
	sigmaf:"Literă greacă mică sigma final",
	sigma:"Literă greacă mică sigma",
	tau:"Literă greacă mică tau",
	upsilon:"Literă greacă mică upsilon",
	phi:"Literă greacă mică phi",
	chi:"Literă greacă mică chi",
	psi:"Literă greacă mică psi",
	omega:"Literă greacă mică omega",
	thetasym:"Literă greacă mică simbol theta",
	upsih:"Simbolul grec upsilon cu cârlig",
	piv:"Simbolul grec pi",
	bull:"bullet\ncerc mic negru",
	hellip:"elipse orizontale\ntrei puncte precursoare",
	prime:"prim\nminute\npicioare",
	Prime:"prim dublu\nsecunde\nţoli",
	oline:"linie deasupra\nlinie de spaţiere deasupra",
	frasl:"linie fracţie",
	weierp:"script capital P\nputere\np Weierstrass",
	image:"I majusculă înnegrită\nparte imaginară",
	real:"R majusculă înnegrită\nsimbol parte reală",
	trade:"semn marcă înregistrată",
	alefsym:"simbol alef\nprimul cardinal transfinit",
	larr:"săgeată spre stânga",
	uarr:"săgeata în sus",
	rarr:"săgeată spre dreapta",
	darr:"săgeata în jos",
	harr:"săgeata stânga dreapta",
	crarr:"săgeata în jos cu colţ spre stânga",
	lArr:"săgeata dublă spre stânga",
	uArr:"săgeata dublă în sus",
	rArr:"săgeata dublă spre dreapta",
	dArr:"săgeata dublă în jos",
	hArr:"săgeata dublă stânga dreapta",
	forall:"pentru toate",
	part:"diferenţiale parţiale",
	exist:"Există",
	empty:"set gol\nset null\ndiametru",
	nabla:"nabla\ndiferenţa înapoi",
	isin:"element al",
	notin:"nu este un element al",
	ni:"conţine ca membru",
	prod:"n produs\nsemnul produs",
	sum:"n suma",
	minus:"semnul minus",
	lowast:"operatorul asterisk",
	radic:"rădăcină pătrată\nsemnul radical",
	prop:"proporţional cu",
	infin:"infinit",
	ang:"unghi",
	and:"şi logic\npană",
	or:"sau logic\nV",
	cap:"intersecţie\ncăciulă",
	cup:"reuniune\ncupă","int":"integral",
	there4:"de aceea",
	sim:"operator tilda\nvariază cu\nsimilar cu",
	cong:"aproximativ egal cu",
	asymp:"aproape egal cu\nasimptotic la",
	ne:"nu este egal cu",
	equiv:"identic cu",
	le:"mai mic sau egal cu",
	ge:"mai mare sau egal cu",
	sub:"subset al",
	sup:"superset al",
	nsub:"nu este un subset al",
	sube:"subset al sau egal cu",
	supe:"superset al sau egal cu",
	oplus:"plus încercuit\nsumă directă",
	otimes:"multiplicator încercuit\nprodus vectorial",
	perp:"up tack\northogonal to\nperpendicular",
	sdot:"operator punct",
	lceil:"plafon stânga\nAPL upstile",
	rceil:"plafon dreapta",
	lfloor:"podea stânga\nAPL downstile",
	rfloor:"podea dreapta",
	lang:"paranteză unghiulară spre stânga",
	rang:"paranteză unghiulară spre dreapta",
	loz:"romb",
	spades:"treflă neagră",
	clubs:"pică neagră\nshamrock",
	hearts:"inimă neagră\nvalentine",
	diams:"romb negru",
	OElig:"Ligatură mare latină OE",
	oelig:"Ligatură mică latină oe",
	Scaron:"Literă mare latină S cu caron",
	scaron:"Literă mică latină s cu caron",
	Yuml:"Literă mare latină Y cu tremă",
	circ:"accent circumflex modificator de literă",
	tilde:"tilda mică",
	ensp:"spaţiu en",
	emsp:"spaţiu em",
	thinsp:"spaţiu îngust",
	zwnj:"zero fără unificator",
	zwj:"zero cu unificator",
	lrm:"semn stânga spre dreapta",
	rlm:"semn dreapta spre stânga",
	ndash:"linie en",
	mdash:"linie em",
	lsquo:"ghilimele simple stânga",
	rsquo:"ghilimele simple dreapta",
	sbquo:"single low-9 semn de citare",
	ldquo:"ghilimele duble stânga",
	rdquo:"ghilimele duble dreapta",
	bdquo:"double low-9 semn de citare",
	dagger:"cruce",
	Dagger:"cruce dublă",
	permil:"semn per mie",
	lsaquo:"ghilimele singure unghiulare spre stânga",
	rsaquo:"ghilimele singure unghiulare spre dreapta",
	euro:"semn euro"
})

//end v1.x content
);
